@@ -318,10 +318,11 @@ public class LibVLC {
     }
 
     public void setAout(int aout) {
-        if (aout == AOUT_OPENSLES && LibVlcUtil.isICSOrLater())
-            this.aout = AOUT_OPENSLES;
-        else
-            this.aout = AOUT_AUDIOTRACK;
+        final HWDecoderUtil.AudioOutput hwaout = HWDecoderUtil.getAudioOutputFromDevice();
+        if (hwaout == HWDecoderUtil.AudioOutput.AUDIOTRACK || hwaout == HWDecoderUtil.AudioOutput.OPENSLES)
+            aout = hwaout == HWDecoderUtil.AudioOutput.OPENSLES ? AOUT_OPENSLES : AOUT_AUDIOTRACK;
+
+        this.aout = aout == AOUT_OPENSLES ? AOUT_OPENSLES : AOUT_AUDIOTRACK;
     }
 
     public int getVout() {
@@ -695,6 +696,12 @@ public class LibVLC {
     public native int getTitle();
     public native void setTitle(int title);
     public native int getChapterCountForTitle(int title);
+    public native int getChapterCount();
+    public native int getChapter();
+    public native String getChapterDescription(int title);
+    public native int previousChapter();
+    public native int nextChapter();
+    public native void setChapter(int chapter);
     public native int getTitleCount();
     public native void playerNavigate(int navigate);
 
