@@ -73,12 +73,9 @@ import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.audio.AudioService;
 import org.videolan.vlc.audio.AudioServiceController;
 import org.videolan.vlc.gui.SidebarAdapter.SidebarEntry;
-import org.videolan.vlc.gui.audio.AudioAlbumsSongsFragment;
 import org.videolan.vlc.gui.audio.AudioBrowserFragment;
 import org.videolan.vlc.gui.audio.AudioPlayer;
-import org.videolan.vlc.gui.audio.EqualizerFragment;
 import org.videolan.vlc.gui.network.NetworkFragment;
-import org.videolan.vlc.gui.video.MediaInfoFragment;
 import org.videolan.vlc.gui.video.VideoGridFragment;
 import org.videolan.vlc.gui.video.VideoListAdapter;
 import org.videolan.vlc.gui.video.VideoPlayerActivity;
@@ -91,24 +88,19 @@ import org.videolan.vlc.util.WeakHandler;
 import org.videolan.vlc.widget.HackyDrawerLayout;
 import org.videolan.vlc.widget.SlidingPaneLayout;
 
-import java.util.Arrays;
-import java.util.HashMap;
-import java.util.List;
-
 public class MainActivity extends ActionBarActivity implements OnItemClickListener, SearchSuggestionsAdapter.SuggestionDisplay, FilterQueryProvider {
     public final static String TAG = "VLC/MainActivity";
 
-    protected static final String ACTION_SHOW_PROGRESSBAR = "org.videolan.vlc.gui.ShowProgressBar";
-    protected static final String ACTION_HIDE_PROGRESSBAR = "org.videolan.vlc.gui.HideProgressBar";
-    protected static final String ACTION_SHOW_TEXTINFO = "org.videolan.vlc.gui.ShowTextInfo";
     public static final String ACTION_SHOW_PLAYER = "org.videolan.vlc.gui.ShowPlayer";
 
     private static final String PREF_FIRST_RUN = "first_run";
 
     private static final int ACTIVITY_RESULT_PREFERENCES = 1;
     private static final int ACTIVITY_SHOW_INFOLAYOUT = 2;
+    private static final int ACTIVITY_SHOW_PROGRESSBAR = 3;
+    private static final int ACTIVITY_HIDE_PROGRESSBAR = 4;
+    private static final int ACTIVITY_SHOW_TEXTINFO = 5;
 
-    private Context mContext;
     private ActionBar mActionBar;
     private SidebarAdapter mSidebarAdapter;
     private AudioPlayer mAudioPlayer;
@@ -139,24 +131,25 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
 
     @Override
     protected void onCreate(Bundle savedInstanceState) {
-        /* Enable the indeterminate progress feature */
-        supportRequestWindowFeature(Window.FEATURE_INDETERMINATE_PROGRESS);
-        if (!LibVlcUtil.hasCompatibleCPU(this)) {
-            Log.e(TAG, LibVlcUtil.getErrorMsg());
-            Intent i = new Intent(this, CompatErrorActivity.class);
-            startActivity(i);
-            finish();
-            super.onCreate(savedInstanceState);
-            return;
-        }
-
-        mContext = this;
-        /* Get the current version from package */
-        mVersionNumber = BuildConfig.VERSION_CODE;
 
         /* Get settings */
         mSettings = PreferenceManager.getDefaultSharedPreferences(this);
 
+        /* Theme must be applied before super.onCreate */
+        applyTheme();
+
+        super.onCreate(savedInstanceState);
+
+        if (!VLCInstance.testCompatibleCPU(this)) {
+            finish();
+            return;
+        }
+        /* Enable the indeterminate progress feature */
+        supportRequestWindowFeature(Window.FEATURE_INDETERMINATE_PROGRESS);
+
+        /* Get the current version from package */
+        mVersionNumber = BuildConfig.VERSION_CODE;
+
         /* Check if it's the first run */
         mFirstRun = mSettings.getInt(PREF_FIRST_RUN, -1) != mVersionNumber;
         if (mFirstRun) {
@@ -165,28 +158,9 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
             Util.commitPreferences(editor);
         }
 
-        try {
-            // Start LibVLC
-            VLCInstance.getLibVlcInstance();
-        } catch (LibVlcException e) {
-            e.printStackTrace();
-            Intent i = new Intent(this, CompatErrorActivity.class);
-            i.putExtra("runtimeError", true);
-            i.putExtra("message", "LibVLC failed to initialize (LibVlcException)");
-            startActivity(i);
-            finish();
-            super.onCreate(savedInstanceState);
-            return;
-        }
-
         /* Load media items from database and storage */
         MediaLibrary.getInstance().loadMediaItems();
 
-        /* Theme must be applied before super.onCreate */
-        applyTheme();
-
-        super.onCreate(savedInstanceState);
-
         /*** Start initializing the UI ***/
 
         setContentView(R.layout.main);
@@ -262,9 +236,6 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
 
         /* Prepare the progressBar */
         IntentFilter filter = new IntentFilter();
-        filter.addAction(ACTION_SHOW_PROGRESSBAR);
-        filter.addAction(ACTION_HIDE_PROGRESSBAR);
-        filter.addAction(ACTION_SHOW_TEXTINFO);
         filter.addAction(ACTION_SHOW_PLAYER);
         registerReceiver(messageReceiver, filter);
 
@@ -513,8 +484,24 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
             menu.findItem(R.id.ml_menu_sortby).setVisible(false);
         }
         else {
+            ISortable sortable = (ISortable) current;
             menu.findItem(R.id.ml_menu_sortby).setEnabled(true);
             menu.findItem(R.id.ml_menu_sortby).setVisible(true);
+            MenuItem item = menu.findItem(R.id.ml_menu_sortby_name);
+                if (sortable.sortDirection(VideoListAdapter.SORT_BY_TITLE) == 1)
+                    item.setTitle(R.string.sortby_name_desc);
+                else
+                    item.setTitle(R.string.sortby_name);
+            item = menu.findItem(R.id.ml_menu_sortby_length);
+                if (sortable.sortDirection(VideoListAdapter.SORT_BY_LENGTH) == 1)
+                    item.setTitle(R.string.sortby_length_desc);
+                else
+                    item.setTitle(R.string.sortby_length);
+            item = menu.findItem(R.id.ml_menu_sortby_date);
+                if (sortable.sortDirection(VideoListAdapter.SORT_BY_DATE) == 1)
+                    item.setTitle(R.string.sortby_date_desc);
+                else
+                    item.setTitle(R.string.sortby_date);
         }
 
         boolean networkSave = current instanceof NetworkFragment && !((NetworkFragment)current).isRootDirectory();
@@ -552,12 +539,18 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
         switch (item.getItemId()) {
             case R.id.ml_menu_sortby_name:
             case R.id.ml_menu_sortby_length:
+            case R.id.ml_menu_sortby_date:
                 if (current == null)
                     break;
-                if (current instanceof ISortable)
-                    ((ISortable) current).sortBy(item.getItemId() == R.id.ml_menu_sortby_name
-                    ? VideoListAdapter.SORT_BY_TITLE
-                    : VideoListAdapter.SORT_BY_LENGTH);
+                if (current instanceof ISortable) {
+                    int sortBy = VideoListAdapter.SORT_BY_TITLE;
+                    if (item.getItemId() == R.id.ml_menu_sortby_length)
+                        sortBy = VideoListAdapter.SORT_BY_LENGTH;
+                    else if(item.getItemId() == R.id.ml_menu_sortby_date)
+                        sortBy = VideoListAdapter.SORT_BY_DATE;
+                    ((ISortable) current).sortBy(sortBy);
+                    supportInvalidateOptionsMenu();
+                }
                 break;
             case R.id.ml_menu_equalizer:
                 showSecondaryFragment("equalizer");
@@ -738,34 +731,7 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
         public void onReceive(Context context, Intent intent) {
             String action = intent.getAction();
 
-            if (action.equalsIgnoreCase(ACTION_SHOW_PROGRESSBAR)) {
-                setSupportProgressBarIndeterminateVisibility(true);
-                getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
-            } else if (action.equalsIgnoreCase(ACTION_HIDE_PROGRESSBAR)) {
-                setSupportProgressBarIndeterminateVisibility(false);
-                getWindow().clearFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
-            } else if (action.equalsIgnoreCase(ACTION_SHOW_TEXTINFO)) {
-                String info = intent.getStringExtra("info");
-                int max = intent.getIntExtra("max", 0);
-                int progress = intent.getIntExtra("progress", 100);
-                mInfoText.setText(info);
-                mInfoProgress.setMax(max);
-                mInfoProgress.setProgress(progress);
-
-                if (info == null) {
-                    /* Cancel any upcoming visibility change */
-                    mHandler.removeMessages(ACTIVITY_SHOW_INFOLAYOUT);
-                    mInfoLayout.setVisibility(View.GONE);
-                }
-                else {
-                    /* Slightly delay the appearance of the progress bar to avoid unnecessary flickering */
-                    if (!mHandler.hasMessages(ACTIVITY_SHOW_INFOLAYOUT)) {
-                        Message m = new Message();
-                        m.what = ACTIVITY_SHOW_INFOLAYOUT;
-                        mHandler.sendMessageDelayed(m, 300);
-                    }
-                }
-            } else if (action.equalsIgnoreCase(ACTION_SHOW_PLAYER)) {
+            if (action.equalsIgnoreCase(ACTION_SHOW_PLAYER)) {
                 showAudioPlayer();
             }
         }
@@ -790,6 +756,36 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
                 case ACTIVITY_SHOW_INFOLAYOUT:
                     ma.mInfoLayout.setVisibility(View.VISIBLE);
                     break;
+                case ACTIVITY_SHOW_PROGRESSBAR:
+                    ma.setSupportProgressBarIndeterminateVisibility(true);
+                    ma.getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
+                    break;
+                case ACTIVITY_HIDE_PROGRESSBAR:
+                    ma.setSupportProgressBarIndeterminateVisibility(false);
+                    ma.getWindow().clearFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
+                    break;
+                case ACTIVITY_SHOW_TEXTINFO:
+                    String info = (String) msg.obj;
+                    int max = msg.arg1;
+                    int progress = msg.arg2;
+                    ma.mInfoText.setText(info);
+                    ma.mInfoProgress.setMax(max);
+                    ma.mInfoProgress.setProgress(progress);
+
+                    if (info == null) {
+                    /* Cancel any upcoming visibility change */
+                        removeMessages(ACTIVITY_SHOW_INFOLAYOUT);
+                        ma.mInfoLayout.setVisibility(View.GONE);
+                    }
+                    else {
+                    /* Slightly delay the appearance of the progress bar to avoid unnecessary flickering */
+                        if (!hasMessages(ACTIVITY_SHOW_INFOLAYOUT)) {
+                            Message m = new Message();
+                            m.what = ACTIVITY_SHOW_INFOLAYOUT;
+                            sendMessageDelayed(m, 300);
+                        }
+                    }
+                    break;
             }
         }
     };
@@ -799,29 +795,20 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
                 getWindow().getDecorView().getRootView().getWindowToken(), 0);
     }
 
-    public static void showProgressBar() {
-        Intent intent = new Intent();
-        intent.setAction(ACTION_SHOW_PROGRESSBAR);
-        VLCApplication.getAppContext().sendBroadcast(intent);
+    public void showProgressBar() {
+        mHandler.obtainMessage(ACTIVITY_SHOW_PROGRESSBAR).sendToTarget();
     }
 
-    public static void hideProgressBar() {
-        Intent intent = new Intent();
-        intent.setAction(ACTION_HIDE_PROGRESSBAR);
-        VLCApplication.getAppContext().sendBroadcast(intent);
+    public void hideProgressBar() {
+        mHandler.obtainMessage(ACTIVITY_HIDE_PROGRESSBAR).sendToTarget();
     }
 
-    public static void sendTextInfo(String info, int progress, int max) {
-        Intent intent = new Intent();
-        intent.setAction(ACTION_SHOW_TEXTINFO);
-        intent.putExtra("info", info);
-        intent.putExtra("progress", progress);
-        intent.putExtra("max", max);
-        VLCApplication.getAppContext().sendBroadcast(intent);
+    public void sendTextInfo(String info, int progress, int max) {
+        mHandler.obtainMessage(ACTIVITY_SHOW_TEXTINFO, max, progress, info).sendToTarget();
     }
 
-    public static void clearTextInfo() {
-        sendTextInfo(null, 0, 100);
+    public void clearTextInfo() {
+        mHandler.obtainMessage(ACTIVITY_SHOW_TEXTINFO, 0, 100, null).sendToTarget();
     }
 
     /**
@@ -889,7 +876,7 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
                 int resId = Util.getResourceFromAttribute(MainActivity.this, R.attr.mini_player_top_shadow);
                 if (resId != 0)
                     mSlidingPane.setShadowResource(resId);
-                mAudioPlayer.setHeaderVisibilities(false, false, true, true, true);
+                mAudioPlayer.setHeaderVisibilities(false, false, true, true, true, false);
                 mRootContainer.setDrawerLockMode(HackyDrawerLayout.LOCK_MODE_UNLOCKED);
                 removeTipViewIfDisplayed();
                 mAudioPlayer.showAudioPlayerTips();
@@ -903,7 +890,7 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
 
             @Override
             public void onPanelClosed() {
-                mAudioPlayer.setHeaderVisibilities(true, true, false, false, false);
+                mAudioPlayer.setHeaderVisibilities(true, true, false, false, false, true);
                 mRootContainer.setDrawerLockMode(HackyDrawerLayout.LOCK_MODE_LOCKED_CLOSED);
                 mAudioPlayer.showPlaylistTips();
             }
@@ -959,7 +946,7 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
         switch (v.getId()){
             case R.id.settings:
             case R.id.settings_icon:
-                startActivityForResult(new Intent(mContext, PreferencesActivity.class), ACTIVITY_RESULT_PREFERENCES);
+                startActivityForResult(new Intent(this, PreferencesActivity.class), ACTIVITY_RESULT_PREFERENCES);
                 break;
             case R.id.about:
             case R.id.about_icon:
@@ -1005,7 +992,7 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
                 requestFocusOnSearch();
             mRootContainer.closeDrawer(mSideMenu);
         }else if (entry.attributeID == R.attr.ic_menu_preferences){
-            startActivityForResult(new Intent(mContext, PreferencesActivity.class), ACTIVITY_RESULT_PREFERENCES);
+            startActivityForResult(new Intent(this, PreferencesActivity.class), ACTIVITY_RESULT_PREFERENCES);
         }
     }
 
